@@ -1,8 +1,8 @@
 #!/bin/bash
 
-ALL_LANGUAGES="ru_RU fi_FI fr_FR en_GB en_US it_IT de_DE es_ES es_MX pl_PL"
+ALL_LANGUAGES="ru_RU fi_FI fr_FR en_GB en_US it_IT de_DE es_ES es_MX pl_PL bg_BG"
 
-xgettext --from-code=UTF-8 --keyword=Q_ --keyword=_  -f po/POTFILES.in -s -C -o po/omweather.pot
+xgettext --from-code=UTF-8 --keyword=_ --keyword=Q_ -f po/POTFILES.in -s -C -o po/omweather.pot
 cd po
 for language in $ALL_LANGUAGES; do
     echo -n "$language: "
