@@ -488,6 +488,16 @@ gint read_config(AppletConfig * config) {
         fill_user_alerts_list(stlist, &app->user_alerts_list);
         g_slist_free(stlist);
     }
+    /* Get Enable Animation flag. Default is TRUE. */
+    value =
+        gconf_client_get(gconf_client, GCONF_KEY_ENABLE_ANIMATION,
+                         NULL);
+    if (value) {
+        config->animation = gconf_value_get_bool(value);
+        gconf_value_free(value);
+    } else
+        config->animation = TRUE;
+
     /* Get icon set name */
     config->icon_set = gconf_client_get_string(gconf_client,
                                                GCONF_KEY_WEATHER_ICON_SET,
@@ -581,6 +591,8 @@ gint read_config(AppletConfig * config) {
         gconf_value_free(value);
     } else
         config->show_weather_for_two_hours = TRUE;
+
+
     /* Hack This parameter is default for SIMPLE mode */
     if (config->mode == SIMPLE_MODE)
         config->show_weather_for_two_hours = TRUE;
@@ -816,7 +828,7 @@ gint read_config(AppletConfig * config) {
                    config->data_valid_interval != 2 &&
                    config->data_valid_interval != 4 &&
                    config->data_valid_interval != 8)) {
-        config->data_valid_interval = 2 * 3600; /* Default value - 2 hours */
+        config->data_valid_interval = 4 * 3600; /* Default value - 4 hours */
         if (gerror)
             g_error_free(gerror);
     } else
@@ -1005,10 +1017,14 @@ void config_save(AppletConfig * config) {
     gconf_client_set_int(gconf_client,
                          GCONF_KEY_WEATHER_UPDATE_INTERVAL,
                          config->update_interval, NULL);
-    /* Save Enable Enable Transparency flag. */
+    /* Save Enable Transparency flag. */
     gconf_client_set_bool(gconf_client,
                           GCONF_KEY_ENABLE_TRANSPARENCY,
                           config->transparency, NULL);
+    /* Save Enable Animation flag. */
+    gconf_client_set_bool(gconf_client,
+                          GCONF_KEY_ENABLE_ANIMATION,
+                          config->animation, NULL);
     /*Save Enable Weather For Two Hours */
     gconf_client_set_bool(gconf_client,
                           GCONF_KEY_SHOW_WEATHER_FOR_TWO_HOURS,
@@ -1121,8 +1137,10 @@ void config_save(AppletConfig * config) {
                           GCONF_KEY_WEATHER_ALERTS_LIST,
                           GCONF_VALUE_STRING, stlist, NULL);
     /* Free stlist */
-    g_slist_foreach(stlist, (GFunc) g_free, NULL);
-    g_slist_free(stlist);
+    if (stlist){
+        g_slist_foreach(stlist, (GFunc) g_free, NULL);
+        g_slist_free(stlist);
+    }
 #ifdef ENABLE_GPS
     /* Save current GPS station */
     if (config->gps_station) {
@@ -1149,6 +1167,9 @@ void config_save(AppletConfig * config) {
                              GCONF_KEY_VIEW_MODE, config->view_mode,
                                                       NULL);
     g_object_unref(gconf_client);
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
 }
 /***********************************************************************************/
 void check_current_station_id(void) {
