@@ -44,12 +44,12 @@
 #define MOON_ICONS		"/usr/share/omweather/moon_icons/"
 /*******************************************************************************/
 void
-destroy_popup_window(gpointer user_data){
+destroy_popup_window(void){
     GSList    *tmp = NULL;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
-    if(!user_data){ /* destroy old popup window */
+    if(app->tab_of_window_popup){ /* destroy old popup window */
         /* free Idles */
         tmp = app->tab_of_window_popup;
         while(tmp){
@@ -68,7 +68,7 @@ destroy_popup_window(gpointer user_data){
         g_slist_free(app->tab_of_window_popup);
         app->tab_of_window_popup = NULL;
     }
-#ifdef CLUTTER
+#if defined CLUTTER || HILDONANIMATION
     /* For end of Clutter animation in popup window */
     free_clutter_objects_list(&app->clutter_objects_in_popup_form);
 #endif
@@ -173,6 +173,8 @@ create_moon_phase_widget(GHashTable *current){
     if(!current)
         return NULL;
 
+    if (!g_hash_table_lookup(current, "moon_phase"))
+        return NULL;
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer + strlen(buffer), sizeof(buffer) - strlen(buffer) - 1,
                 "%s",
@@ -190,7 +192,8 @@ create_moon_phase_widget(GHashTable *current){
         *space_symbol = '_';
     icon_buffer = gdk_pixbuf_new_from_file_at_size(icon, GIANT_ICON_SIZE,
                                                     GIANT_ICON_SIZE, NULL);
-    icon_image = create_icon_widget(icon_buffer, icon, GIANT_ICON_SIZE, &app->clutter_objects_in_popup_form);
+   // icon_image = create_icon_widget(icon_buffer, icon, GIANT_ICON_SIZE, &app->clutter_objects_in_popup_form);
+    icon_image = create_icon_widget(icon_buffer, icon, GIANT_ICON_SIZE, NULL);
 
     if(icon_image)
         gtk_box_pack_start(GTK_BOX(main_widget), icon_image, FALSE, TRUE, 0);
@@ -346,6 +349,11 @@ create_toolbar_box(GtkCallback exit_function, GtkWidget *window, gboolean fullsc
                 *about_button = NULL,
                 *maximize_button = NULL,
                 *close_button = NULL;
+#ifdef OS2009
+    #define BUTTON_ICON_SIZE 64
+#else
+    #define BUTTON_ICON_SIZE 40
+#endif
     /* Bottom buttons box */
     /*buttons_box = gtk_toolbar_new();
     hildon_window_add_toolbar(HILDON_WINDOW(window_popup),GTK_TOOLBAR(buttons_box));*/
@@ -354,31 +362,31 @@ create_toolbar_box(GtkCallback exit_function, GtkWidget *window, gboolean fullsc
 
     /* Settings button */
     /*settings_button = create_tool_item(BUTTON_ICONS, "settings", 40);*/
-    settings_button = create_button_with_image(BUTTON_ICONS, "settings", 40, FALSE, FALSE);
+    settings_button = create_button_with_image(BUTTON_ICONS, "settings", BUTTON_ICON_SIZE, FALSE, FALSE);
     g_signal_connect(G_OBJECT(settings_button), "button-release-event",
                      G_CALLBACK(settings_button_handler),
                      (gpointer)app->popup_window);
     /* Refresh buton */
     /*refresh_button = create_tool_item(BUTTON_ICONS, "refresh", 40);*/
-    refresh_button = create_button_with_image(BUTTON_ICONS, "refresh", 40, FALSE, FALSE);
+    refresh_button = create_button_with_image(BUTTON_ICONS, "refresh", BUTTON_ICON_SIZE, FALSE, FALSE);
         g_signal_connect(G_OBJECT(refresh_button), "button-release-event",
                      G_CALLBACK(refresh_button_handler),
                      (gpointer)app->popup_window);
     /* About buton */
     /*about_button = create_tool_item(BUTTON_ICONS, "about", 40);*/
-    about_button = create_button_with_image(BUTTON_ICONS, "about", 40, FALSE, FALSE);
+    about_button = create_button_with_image(BUTTON_ICONS, "about", BUTTON_ICON_SIZE, FALSE, FALSE);
     g_signal_connect(G_OBJECT(about_button), "button-release-event",
                         G_CALLBACK(about_button_handler),
                         NULL);
     /* Close button */
     /*close_button = create_tool_item(BUTTON_ICONS, "close", 40);*/
-    close_button = create_button_with_image(BUTTON_ICONS, "close", 40, FALSE, FALSE);
+    close_button = create_button_with_image(BUTTON_ICONS, "close", BUTTON_ICON_SIZE, FALSE, FALSE);
     g_signal_connect(G_OBJECT(close_button), "button-release-event",
                         G_CALLBACK(exit_function),
                         (gpointer)window);
     /* Fullscreen button */
     /*maximize_button = create_tool_item(BUTTON_ICONS, "maximize", 40);*/
-    maximize_button = create_button_with_image(BUTTON_ICONS, "maximize", 40, FALSE, FALSE);
+    maximize_button = create_button_with_image(BUTTON_ICONS, "maximize", BUTTON_ICON_SIZE, FALSE, FALSE);
     g_signal_connect(G_OBJECT(maximize_button), "button-release-event",
                         G_CALLBACK(maximize_button_handler),
                         (gpointer)window);
@@ -615,7 +623,7 @@ weather_window_popup(GtkWidget *widget, GdkEvent *event, gpointer user_data){
             hildon_banner_show_information(app->main_window,
                             NULL,
                             _("No weather data for this day."));
-            destroy_popup_window(NULL);
+            destroy_popup_window();
             return FALSE;
         }
         else{
@@ -627,7 +635,7 @@ weather_window_popup(GtkWidget *widget, GdkEvent *event, gpointer user_data){
                         hildon_banner_show_information(app->main_window,
                                     NULL,
                                     _("No current weather data."));
-                        destroy_popup_window(NULL);
+                        destroy_popup_window();
                         return FALSE;
                     }
                 }
@@ -683,7 +691,7 @@ settings_button_handler(GtkWidget *button, GdkEventButton *event,
 #endif
 /* For debug speed of creating setting window */
 /* time_start();  */
-    destroy_popup_window(NULL);
+    destroy_popup_window();
     weather_window_settings(NULL, (gpointer)day_number);
 /* fprintf(stderr,"Time: %lf msec Pi = %lf\n",time_stop(),weather_window_settings);*/
 }
@@ -694,7 +702,7 @@ void refresh_button_handler(GtkWidget *button, GdkEventButton *event,
     START_FUNCTION;
 #endif
     if(app->popup_window)
-        destroy_popup_window(NULL);
+        destroy_popup_window();
     update_weather(TRUE);
 }
 /*******************************************************************************/
@@ -715,7 +723,7 @@ void popup_close_button_handler(GtkWidget *button, GdkEventButton *event,
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
-    destroy_popup_window(NULL);
+    destroy_popup_window();
 }
 /*******************************************************************************/
 GtkWidget*
@@ -862,7 +870,8 @@ create_day_tab(GHashTable *current, GHashTable *day, gchar **day_name){
         icon = gdk_pixbuf_new_from_file_at_size(buffer,
                             BIG_ICON_SIZE,
                             BIG_ICON_SIZE, NULL);
-        day_icon = create_icon_widget(icon, buffer, BIG_ICON_SIZE, &app->clutter_objects_in_popup_form);
+//        day_icon = create_icon_widget(icon, buffer, BIG_ICON_SIZE, &app->clutter_objects_in_popup_form);
+        day_icon = create_icon_widget(icon, buffer, BIG_ICON_SIZE, NULL);
         gtk_box_pack_start(GTK_BOX(day_icon_text_hbox),
                             day_icon, TRUE, TRUE, 5);
         /* prepare day text */
@@ -969,7 +978,8 @@ create_day_tab(GHashTable *current, GHashTable *day, gchar **day_name){
     icon = gdk_pixbuf_new_from_file_at_size(buffer,
                         BIG_ICON_SIZE,
                         BIG_ICON_SIZE, NULL);
-    night_icon = create_icon_widget(icon, buffer, BIG_ICON_SIZE, &app->clutter_objects_in_popup_form);
+//    night_icon = create_icon_widget(icon, buffer, BIG_ICON_SIZE, &app->clutter_objects_in_popup_form);
+    night_icon = create_icon_widget(icon, buffer, BIG_ICON_SIZE, NULL);
     gtk_box_pack_start(GTK_BOX(night_icon_text_hbox),
                             night_icon, TRUE, TRUE, 5);
     /* prepare night text */
@@ -1092,95 +1102,114 @@ create_current_tab(GHashTable *current){
                 (char*)g_hash_table_lookup(current, "icon"));
     icon = gdk_pixbuf_new_from_file_at_size(buffer, GIANT_ICON_SIZE,
                                             GIANT_ICON_SIZE, NULL);
-    icon_image = create_icon_widget(icon, buffer, GIANT_ICON_SIZE, &app->clutter_objects_in_popup_form);
+/* This code for animation */
+/*    icon_image = create_icon_widget(icon, buffer, GIANT_ICON_SIZE, &app->clutter_objects_in_popup_form); */
+    icon_image = create_icon_widget(icon, buffer, GIANT_ICON_SIZE, NULL);
     gtk_box_pack_start(GTK_BOX(icon_text_hbox), icon_image, TRUE, TRUE, 0);
     /* temperature */
     memset(buffer, 0, sizeof(buffer));
-    sprintf(buffer, "%s\n", (char *)hash_table_find(g_hash_table_lookup(current, "title"), FALSE));
+    if (g_hash_table_lookup(current, "title"))
+        sprintf(buffer, "%s\n", (char *)hash_table_find(g_hash_table_lookup(current, "title"), FALSE));
     sprintf(buffer + strlen(buffer), "%s",  _("Temperature: "));
-    sprintf(buffer + strlen(buffer), "  %d\302\260",
-                ((app->config->temperature_units == CELSIUS) ?
-                ( atoi(g_hash_table_lookup(current, "day_hi_temperature"))) :
-                ( (int)c2f(atoi(g_hash_table_lookup(current, "day_hi_temperature"))))));
-    (app->config->temperature_units == CELSIUS) ? ( strcat(buffer, _("C\n")) )
-                                                : ( strcat(buffer, _("F\n")) );
+    if (g_hash_table_lookup(current, "day_hi_temperature")){
+        sprintf(buffer + strlen(buffer), "  %d\302\260",
+                    ((app->config->temperature_units == CELSIUS) ?
+                    ( atoi(g_hash_table_lookup(current, "day_hi_temperature"))) :
+                    ( (int)c2f(atoi(g_hash_table_lookup(current, "day_hi_temperature"))))));
+        (app->config->temperature_units == CELSIUS) ? ( strcat(buffer, _("C\n")) )
+                                                    : ( strcat(buffer, _("F\n")) );
+    }
     /* feels like */
     sprintf(buffer + strlen(buffer), "%s", _("Feels like:"));
-    sprintf(buffer + strlen(buffer), "  %d\302\260",
-                (app->config->temperature_units == CELSIUS) ?
-                (atoi(g_hash_table_lookup(current, "feel_like"))) :
-                ((int)c2f(atoi(g_hash_table_lookup(current, "feel_like")))));
-    (app->config->temperature_units == CELSIUS) ? ( strcat(buffer, _("C\n")) )
-                                                : ( strcat(buffer, _("F\n")) );
-/* humidity */
-    if( strcmp(g_hash_table_lookup(current, "humidity"), "N/A") ){
-        sprintf(buffer + strlen(buffer), "%s", _("Humidity:"));
-        sprintf(buffer + strlen(buffer), "  %d%%\n",
-                atoi(g_hash_table_lookup(current, "humidity")));
+    if (g_hash_table_lookup(current, "feel_like")){
+        sprintf(buffer + strlen(buffer), "  %d\302\260",
+                    (app->config->temperature_units == CELSIUS) ?
+                    (atoi(g_hash_table_lookup(current, "feel_like"))) :
+                    ((int)c2f(atoi(g_hash_table_lookup(current, "feel_like")))));
+        (app->config->temperature_units == CELSIUS) ? ( strcat(buffer, _("C\n")) )
+                                                    : ( strcat(buffer, _("F\n")) );
     }
+/* humidity */
+    if (g_hash_table_lookup(current, "humidity"))
+        if( strcmp(g_hash_table_lookup(current, "humidity"), "N/A") ){
+            sprintf(buffer + strlen(buffer), "%s", _("Humidity:"));
+            sprintf(buffer + strlen(buffer), "  %d%%\n",
+                    atoi(g_hash_table_lookup(current, "humidity")));
+        }
 /* visible */
-    if( strcmp(g_hash_table_lookup(current, "visible"), "N/A") ){
-        sprintf(buffer + strlen(buffer), "%s", _("Visible:"));
-        if( !strcmp(g_hash_table_lookup(current, "visible"), "Unlimited") )
-            sprintf(buffer + strlen(buffer), "  %s\n",
-                    (char*)hash_table_find("Unlimited", FALSE));
-        else{
-            tmp_distance = atof(g_hash_table_lookup(current, "visible"));
-            switch(app->config->distance_units){
-                default:
-                case METERS: units = _("m"); tmp_distance *= 1000.0f; break;
-                case KILOMETERS: units = _("km"); tmp_distance *= 1.0f; break;
-                case MILES: units = _("mi"); tmp_distance /= 1.609344f; break;
-                case SEA_MILES: units = _("mi"); tmp_distance /= 1.852f; break;
+    if (g_hash_table_lookup(current, "visible")){
+        if( strcmp(g_hash_table_lookup(current, "visible"), "N/A") ){
+            sprintf(buffer + strlen(buffer), "%s", _("Visible:"));
+            if( !strcmp(g_hash_table_lookup(current, "visible"), "Unlimited") )
+                sprintf(buffer + strlen(buffer), "  %s\n",
+                        (char*)hash_table_find("Unlimited", FALSE));
+            else{
+                tmp_distance = atof(g_hash_table_lookup(current, "visible"));
+                switch(app->config->distance_units){
+                    default:
+                    case METERS: units = _("m"); tmp_distance *= 1000.0f; break;
+                    case KILOMETERS: units = _("km"); tmp_distance *= 1.0f; break;
+                    case MILES: units = _("mi"); tmp_distance /= 1.609344f; break;
+                    case SEA_MILES: units = _("mi"); tmp_distance /= 1.852f; break;
+                }
+                sprintf(buffer + strlen(buffer), "  %.2f %s\n", tmp_distance, units);
             }
-            sprintf(buffer + strlen(buffer), "  %.2f %s\n", tmp_distance, units);
         }
     }
 /* pressure */
-    if( strcmp(g_hash_table_lookup(current, "pressure"), "N/A") ){
-        sprintf(buffer + strlen(buffer), "%s", _("Pressure:"));
-        tmp_pressure = atof(g_hash_table_lookup(current, "pressure"));
-        switch(app->config->pressure_units){
-            default:
-            case MB: units = _("mb"); break;
-            case INCH: units = _("inHg"); tmp_pressure = mb2inch(tmp_pressure); break;
-            case MM: units = _("mmHg"); tmp_pressure = mb2mm(tmp_pressure); break;
+    if (g_hash_table_lookup(current, "pressure")){
+        if( strcmp(g_hash_table_lookup(current, "pressure"), "N/A") ){
+            sprintf(buffer + strlen(buffer), "%s", _("Pressure:"));
+            tmp_pressure = atof(g_hash_table_lookup(current, "pressure"));
+            switch(app->config->pressure_units){
+                default:
+                case MB: units = _("mb"); break;
+                case INCH: units = _("inHg"); tmp_pressure = mb2inch(tmp_pressure); break;
+                case MM: units = _("mmHg"); tmp_pressure = mb2mm(tmp_pressure); break;
+            }
+            sprintf(buffer + strlen(buffer), "  %.2f %s,", tmp_pressure, units);
+            if (g_hash_table_lookup(current, "pressure_direction"))
+                sprintf(buffer + strlen(buffer), "  %s\n",
+                    (char *)hash_table_find(g_hash_table_lookup(current, "pressure_direction"), FALSE));
+            else
+                sprintf(buffer + strlen(buffer), "\n");
         }
-        sprintf(buffer + strlen(buffer), "  %.2f %s,", tmp_pressure, units);
-        sprintf(buffer + strlen(buffer), "  %s\n",
-                (char *)hash_table_find(g_hash_table_lookup(current, "pressure_direction"), FALSE));
     }
 /* wind */
+    if (g_hash_table_lookup(current, "wind_direction"))
     if( strcmp(g_hash_table_lookup(current, "wind_direction"), "N/A") ){
         sprintf(buffer + strlen(buffer), "%s", _("Wind:"));
         sprintf(buffer + strlen(buffer), "  %s\n",
                     (char *)hash_table_find(g_hash_table_lookup(current, "wind_direction"), FALSE));
-    if( strcmp(g_hash_table_lookup(current, "wind_speed"), "N/A") )
-        sprintf(buffer + strlen(buffer), "%s", _("Speed:"));
-        switch(app->config->wind_units){
-            case BEAUFORT_SCALE:
-                sprintf(buffer + strlen(buffer), "  %i\n",
-                        (int)convert_wind_units(app->config->wind_units, atof(g_hash_table_lookup(current, "wind_speed"))));
-            break;
-            case KILOMETERS_H:
-                sprintf(buffer + strlen(buffer), "  %i %s\n",
-                        (int)convert_wind_units(app->config->wind_units, atof(g_hash_table_lookup(current, "wind_speed"))),
-                        (char*)hash_table_find((gpointer)wind_units_str[app->config->wind_units], FALSE));
-            break;
-            default:
-                sprintf(buffer + strlen(buffer), "  %.2f %s\n",
-                        convert_wind_units(app->config->wind_units, atof(g_hash_table_lookup(current, "wind_speed"))),
-                        (char*)hash_table_find((gpointer)wind_units_str[app->config->wind_units], FALSE));
-            break;
+        if (g_hash_table_lookup(current, "wind_speed")){
+            if( strcmp(g_hash_table_lookup(current, "wind_speed"), "N/A") )
+                sprintf(buffer + strlen(buffer), "%s", _("Speed:"));
+                switch(app->config->wind_units){
+                    case BEAUFORT_SCALE:
+                        sprintf(buffer + strlen(buffer), "  %i\n",
+                                (int)convert_wind_units(app->config->wind_units, atof(g_hash_table_lookup(current, "wind_speed"))));
+                    break;
+                    case KILOMETERS_H:
+                        sprintf(buffer + strlen(buffer), "  %i %s\n",
+                                (int)convert_wind_units(app->config->wind_units, atof(g_hash_table_lookup(current, "wind_speed"))),
+                                (char*)hash_table_find((gpointer)wind_units_str[app->config->wind_units], FALSE));
+                    break;
+                    default:
+                        sprintf(buffer + strlen(buffer), "  %.2f %s\n",
+                                convert_wind_units(app->config->wind_units, atof(g_hash_table_lookup(current, "wind_speed"))),
+                                (char*)hash_table_find((gpointer)wind_units_str[app->config->wind_units], FALSE));
+                    break;
+                }
         }
     }
 /* gust */
-    if( strcmp(g_hash_table_lookup(current, "wind_gust"), "N/A") ){
-        sprintf(buffer + strlen(buffer), "%s", _("Gust:"));
-        sprintf(buffer + strlen(buffer), "  %.2f %s\n",
-                convert_wind_units(app->config->wind_units, atof(g_hash_table_lookup(current, "wind_gust"))),
-                (char*)hash_table_find((gpointer)wind_units_str[app->config->wind_units], FALSE));
-    }
+    if (g_hash_table_lookup(current, "wind_gust"))
+        if( strcmp(g_hash_table_lookup(current, "wind_gust"), "N/A") ){
+            sprintf(buffer + strlen(buffer), "%s", _("Gust:"));
+            sprintf(buffer + strlen(buffer), "  %.2f %s\n",
+                    convert_wind_units(app->config->wind_units, atof(g_hash_table_lookup(current, "wind_gust"))),
+                    (char*)hash_table_find((gpointer)wind_units_str[app->config->wind_units], FALSE));
+        }
 
     text = gtk_label_new(buffer);
     set_font(text, NULL, 14);
@@ -1241,7 +1270,8 @@ GtkWidget* create_hour_tab(void){
                 (char*)g_hash_table_lookup(hour_weather, "hour_icon"));
         icon = gdk_pixbuf_new_from_file_at_size(buffer, SMALL_ICON_SIZE,
                                                    SMALL_ICON_SIZE, NULL);
-        icon_image = create_icon_widget(icon, buffer, SMALL_ICON_SIZE, &app->clutter_objects_in_popup_form);
+//        icon_image = create_icon_widget(icon, buffer, SMALL_ICON_SIZE, &app->clutter_objects_in_popup_form);
+        icon_image = create_icon_widget(icon, buffer, SMALL_ICON_SIZE, NULL);
         gtk_box_pack_start(GTK_BOX(icon_text_hbox), icon_image, TRUE, FALSE, 0);
         memset(buffer, 0, sizeof(buffer));
 /* hour */
@@ -1451,3 +1481,14 @@ popup_window_expose(GtkWidget *widget, GdkEventExpose *event){
 }
 #endif
 /*******************************************************************************/
+#ifdef HILDONANIMATION
+/* For start of Clutter animation in popup window */
+void
+popup_window_expose(GtkWidget *widget, GdkEventExpose *event){
+    show_hildon_animation(app->clutter_objects_in_popup_form, app->popup_window);
+    gtk_widget_show_all(widget);
+    g_signal_handlers_disconnect_by_func(G_OBJECT(widget),G_CALLBACK(popup_window_expose),NULL);
+}
+#endif
+
+/*******************************************************************************/
