@@ -88,8 +88,6 @@ weather_simple_window_popup(GtkWidget *widget, gpointer user_data){
     gtk_window_set_title(GTK_WINDOW(window), _("Forecast"));
 
     gtk_container_add(GTK_CONTAINER(window), create_mainbox_for_forecast_window(window, user_data));
-    gtk_widget_show(window);
-
 #if defined OS2009
     menu = create_view_menu();
     hildon_window_set_app_menu(HILDON_WINDOW(window), menu);
@@ -131,10 +129,12 @@ get_next_station_name(const gchar *current_station_name, GtkListStore *user_stat
         /* Skip Empty stations */
         if(ready && !strcmp(station_name, " ")){
             skipped = TRUE;
+            g_free(station_name);
             gtk_tree_path_next(path);
             valid = gtk_tree_model_get_iter(GTK_TREE_MODEL(app->user_stations_list),
                                         &iter, path);
             if(!valid){
+                gtk_tree_path_free(path);
                 path = gtk_tree_path_new_first();
                 valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(app->user_stations_list),
                                         &iter);
@@ -163,7 +163,7 @@ get_next_station_name(const gchar *current_station_name, GtkListStore *user_stat
             }
         }
     }
-   gtk_tree_path_free(path);
+    gtk_tree_path_free(path);
     return station_name;
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
@@ -181,9 +181,11 @@ weather_simple_window_redraw(GtkWidget *window){
     START_FUNCTION;
 #endif
 
-
     main_vbox = (GtkWidget*)g_object_get_data(G_OBJECT(window), "main_vbox");
     user_data = g_object_get_data(G_OBJECT(window), "user_data");
+    #if defined CLUTTER || defined HILDONANIMATION
+        free_clutter_objects_list(&app->clutter_objects_in_popup_form);
+    #endif
     if (main_vbox)
         gtk_widget_destroy(main_vbox);
     main_vbox =  create_mainbox_for_forecast_window(window, user_data);
@@ -302,7 +304,10 @@ create_weather_collapsed_view(GtkWidget *vbox, gint day_number){
     /* pack childs to the scrolled window */
     gtk_scrolled_window_add_with_viewport(scrolled_window, main_vbox);
 #endif
-
+#if defined CLUTTER || HILDONANIMATION
+    /* For end of Clutter animation in popup window */
+        free_clutter_objects_list(&app->clutter_objects_in_popup_form);
+#endif
     days = (GSList*)g_hash_table_lookup(app->station_data, "forecast");
     if(days){
         while(days){
@@ -326,7 +331,8 @@ create_weather_collapsed_view(GtkWidget *vbox, gint day_number){
                         (char*)g_hash_table_lookup(day, "day_icon"));
             icon_buffer = gdk_pixbuf_new_from_file_at_size(icon, SMALL_ICON_SIZE,
                                                             SMALL_ICON_SIZE, NULL);
-            icon_image = create_icon_widget(icon_buffer, icon, SMALL_ICON_SIZE, &app->clutter_objects_in_popup_form);
+/*            icon_image = create_icon_widget(icon_buffer, icon, SMALL_ICON_SIZE, &app->clutter_objects_in_popup_form); */
+            icon_image = create_icon_widget(icon_buffer, icon, SMALL_ICON_SIZE, NULL);
             if(icon_image){
                 gtk_box_pack_start(GTK_BOX(line_hbox), icon_image, FALSE, TRUE, 0);
                 gtk_box_pack_start(GTK_BOX(main_vbox), line, TRUE, TRUE, 0);
@@ -462,6 +468,11 @@ create_weather_collapsed_view(GtkWidget *vbox, gint day_number){
         set_font(label, NULL, 24);
     }
     gtk_widget_show_all(scrolled_window);
+
+#ifdef HILDONANIMATION 
+    g_signal_connect_after(scrolled_window, "expose-event", G_CALLBACK(popup_simple_window_expose), NULL);
+#endif
+
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
@@ -504,6 +515,11 @@ create_weather_expanded_view(GtkWidget *vbox, gint day_number){
     hildon_helper_set_thumb_scrollbar(scrolled_window, TRUE);
     gtk_scrolled_window_add_with_viewport(scrolled_window, main_vbox);
 #endif
+#if defined CLUTTER || HILDONANIMATION
+    /* For end of Clutter animation in popup window */
+        free_clutter_objects_list(&app->clutter_objects_in_popup_form);
+#endif
+ 
     gtk_widget_set_size_request(scrolled_window, -1, -1);
     if(!app->station_data)
         return NULL;
@@ -564,11 +580,14 @@ create_weather_expanded_view(GtkWidget *vbox, gint day_number){
             g_object_set_data(G_OBJECT(scrolled_window), "selected_widget", (gpointer)line);
         tmp = g_slist_next(tmp);
         i++;
+        g_free(day_name);
     }
     
     gtk_widget_show_all(main_vbox);
     gtk_widget_show_all(scrolled_window);
-    g_free(day_name);
+#ifdef HILDONANIMATION 
+    g_signal_connect_after(scrolled_window, "expose-event", G_CALLBACK(popup_simple_window_expose), NULL);
+#endif
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
@@ -618,12 +637,11 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
     GtkWidget       *scrolled_window = NULL,
                     *main_vbox = NULL,
                     *line = NULL,
-                    *line_hbox = NULL,
                     *line_text = NULL,
 #if !defined OS2009
                     *vscrollbar = NULL,
 #endif
-                    *icon_text_hbox = NULL;
+                    *line_hbox = NULL;
     GdkPixbuf       *icon;
     GtkWidget       *icon_image;
     const gchar     *wind_units_str[] = {"m/s", "km/h", "mi/h" };
@@ -668,7 +686,6 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
 
     hours_weather = g_hash_table_lookup(g_hash_table_lookup(app->station_data, "detail"), "hours_data");
 
-
     if(hours_weather){
         while(hours_weather){
             hour_weather = (GHashTable*)hours_weather->data;
@@ -688,7 +705,6 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
             memset(buff, 0, sizeof(buff));
 
             /*Prepare date from xml file*/
-
             snprintf(hour_last_update + strlen(hour_last_update),
                     sizeof(hour_last_update) - strlen(hour_last_update) - 1,
                     "%s",
@@ -700,28 +716,29 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
             *hour_last_update = 0;
             strcat(hour_last_update, buff);
             strcat(hour_last_update, " ");
-            strcat(hour_last_update, (char*)g_hash_table_lookup(hour_weather, "hours"));
-            strcat(hour_last_update, ":00:00");
+            if (g_hash_table_lookup(hour_weather, "hours")){
+                strcat(hour_last_update, (char*)g_hash_table_lookup(hour_weather, "hours"));
+                strcat(hour_last_update, ":00:00");
+            }
 
             strptime(hour_last_update, "%D %T", &tmp_tm);
             hours_time = mktime(&tmp_tm);
-            if((count > 1) && 
-                        (!strcmp((char*)g_hash_table_lookup(hour_weather, "hours"), "00")))
-                new_day = TRUE;
-            if(new_day)
-                hours_time += 24*60*60;
-            difference = difftime(hours_time, current_time);
-
+            if (g_hash_table_lookup(hour_weather, "hours")){
+                if((count > 1) && 
+                            (!strcmp((char*)g_hash_table_lookup(hour_weather, "hours"), "00")))
+                    new_day = TRUE;
+                if(new_day)
+                    hours_time += 24*60*60;
+                difference = difftime(hours_time, current_time);
+            }    
             if((difference < 0 && difference > -60*60) || difference >= 0 ||
                                       (prev_difference > 0 &&  difference<0)) {
-
                 flag = TRUE; 
                 line =  gtk_button_new();
                 gtk_button_set_focus_on_click(GTK_BUTTON(line), FALSE);
                             gtk_button_set_relief(GTK_BUTTON(line), GTK_RELIEF_NONE);
-                icon_text_hbox = gtk_hbox_new(FALSE, 0);
                 *buffer = 0;
-                g_object_set_data(G_OBJECT(line), "scrolled_window", 
+                g_object_set_data(G_OBJECT(line), "scrolled_window",
                                                        (gpointer)scrolled_window);
                 g_object_set_data(G_OBJECT(line), "vbox", (gpointer)vbox);
                 g_signal_connect(G_OBJECT(line), "clicked",
@@ -736,11 +753,13 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
                            (char*)g_hash_table_lookup(hour_weather, "hour_icon"));
                 icon = gdk_pixbuf_new_from_file_at_size(buffer, SMALL_ICON_SIZE,
                                                       SMALL_ICON_SIZE, NULL);
+/*                icon_image = create_icon_widget(icon, buffer, SMALL_ICON_SIZE,
+                            &app->clutter_objects_in_popup_form);
+*/
                 icon_image = create_icon_widget(icon, buffer, SMALL_ICON_SIZE,
-                                             &app->clutter_objects_in_popup_form);
+                                             NULL);
                 if(icon_image){
-                    gtk_box_pack_start(GTK_BOX(line_hbox), icon_image, FALSE, 
-                                                                          TRUE, 0);
+                    gtk_box_pack_start(GTK_BOX(line_hbox), icon_image, FALSE, TRUE, 0);
                     gtk_box_pack_start(GTK_BOX(main_vbox), line, TRUE, TRUE, 0);
                 }
 
@@ -756,25 +775,29 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
                                     sizeof(buffer) - strlen(buffer) - 1,"</span>");
                 *tmp = 0;
                 /* temperature */
-                sprintf(tmp, " %d\302\260",
-                        ((app->config->temperature_units == CELSIUS) ?
-                       ( atoi(g_hash_table_lookup(hour_weather, "hour_temperature"))) :
-                  ( (int)c2f(atoi(g_hash_table_lookup(hour_weather, "hour_temperature"))))));
-                (app->config->temperature_units == CELSIUS) ? ( strcat(tmp, _("C")))
-                                               : ( strcat(tmp, _("F")));
+                if (g_hash_table_lookup(hour_weather, "hour_temperature")){
+                    sprintf(tmp, " %d\302\260",
+                            ((app->config->temperature_units == CELSIUS) ?
+                           ( atoi(g_hash_table_lookup(hour_weather, "hour_temperature"))) :
+                      ( (int)c2f(atoi(g_hash_table_lookup(hour_weather, "hour_temperature"))))));
+                    (app->config->temperature_units == CELSIUS) ? ( strcat(tmp, _("C")))
+                                                   : ( strcat(tmp, _("F")));
+                 }
 
                 /* feels like */
-                sprintf(tmp + strlen(tmp), " (%s  %d\302\260", _("feels like"),
-                             (app->config->temperature_units == CELSIUS) ?
-                             (atoi(g_hash_table_lookup(hour_weather, "hour_feels_like"))) :
-                    ((int)c2f(atoi(g_hash_table_lookup(hour_weather, "hour_feels_like")))));
-                (app->config->temperature_units == CELSIUS) ? ( strcat(tmp, _("C")))
-                                                             : ( strcat(tmp, _("F")));
-                sprintf(tmp + strlen(tmp), ")");
+                if (g_hash_table_lookup(hour_weather, "hour_feels_like")){
+                    sprintf(tmp + strlen(tmp), " (%s  %d\302\260", _("feels like"),
+                                 (app->config->temperature_units == CELSIUS) ?
+                                 (atoi(g_hash_table_lookup(hour_weather, "hour_feels_like"))) :
+                        ((int)c2f(atoi(g_hash_table_lookup(hour_weather, "hour_feels_like")))));
+                    (app->config->temperature_units == CELSIUS) ? ( strcat(tmp, _("C")))
+                                                                 : ( strcat(tmp, _("F")));
+                    sprintf(tmp + strlen(tmp), ")");
+                }
 
                 /* title */
                 if(g_hash_table_lookup(hour_weather, "hour_title"))
-                snprintf(tmp + strlen(tmp), sizeof(tmp) - strlen(tmp) - 1," ,%s, ",
+                snprintf(tmp + strlen(tmp), sizeof(tmp) - strlen(tmp) - 1," , %s, ",
                        (char*)hash_table_find(g_hash_table_lookup(hour_weather, "hour_title"), 
                         FALSE));
 
@@ -814,6 +837,7 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
                                         sizeof(buffer) - strlen(buffer) - 1, 
                                         "<i>%s</i>", tmp);
 
+
                 line_text = gtk_label_new(NULL);
                 gtk_label_set_justify(GTK_LABEL(line_text), GTK_JUSTIFY_FILL);
                 gtk_label_set_markup(GTK_LABEL(line_text), buffer);
@@ -828,7 +852,6 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
             prev_difference = difference;
             hours_weather = g_slist_next(hours_weather);
             difference = 0;
-            flag = FALSE;
         }
 
         if(!hours_weather)
@@ -877,66 +900,79 @@ create_view_menu(void){
                         G_CALLBACK(donation_button_handler), NULL);
     gtk_widget_show_all(menu_item);
     hildon_app_menu_append(menu, GTK_BUTTON(menu_item));
-
+ 
     gtk_widget_show_all(GTK_WIDGET(menu));
     return menu;
 }
-#endif
 /*******************************************************************************/
- void
- click_url_and_destroy_window(GtkWidget* button, gpointer window)
- {
- #ifdef DEBUGFUNCTIONCALL
-     START_FUNCTION;
- #endif
+/* For start of Clutter animation in popup window */
+void
+popup_simple_window_expose(GtkWidget *widget, GdkEventExpose *event){
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
  
-     click_url(button);
-     gtk_widget_destroy(GTK_WIDGET(window));
- 
- #ifdef DEBUGFUNCTIONCALL
-     END_FUNCTION;
- #endif
- 
- }
- /*******************************************************************************/
- void donation_button_handler(void){
-     GtkWidget   *dialog, *url, *label;
-     char    tmp_buff[2048];
-     gint    result;
- #ifdef DEBUGFUNCTIONCALL
-     START_FUNCTION;
- #endif
- 
- #if !OS2009
-     dialog =
-         gtk_dialog_new_with_buttons(_("Donation"), NULL,
-                                     GTK_DIALOG_MODAL |
-                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-                                     _("OK"), GTK_RESPONSE_ACCEPT, NULL);
- #else
-     dialog =
-         gtk_dialog_new_with_buttons(_("Donation"), NULL,
-                                     GTK_DIALOG_MODAL |
-                                     GTK_DIALOG_DESTROY_WITH_PARENT, NULL);
- 
- #endif
- /* text */
-     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),
-                         label = gtk_label_new(_("You can make donation here: ")),
-                         FALSE, FALSE, 5);
-     set_font(label, NULL, 20);
- /* url */
-     url = gtk_button_new_with_label("http://omweather.garage.maemo.org/donation.html");
-     gtk_button_set_relief(GTK_BUTTON(url), GTK_RELIEF_NONE);
-     g_signal_connect(url, "clicked",
-           G_CALLBACK(click_url_and_destroy_window), dialog);
-     gtk_button_set_focus_on_click(GTK_BUTTON(url), FALSE);
-     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), url, FALSE, FALSE, 5);
-     set_font(url, NULL, 12);
-     gtk_widget_show_all(dialog);
- /* start dialog window */
-     result = gtk_dialog_run(GTK_DIALOG(dialog));
-     gtk_widget_destroy(dialog);
- }
+#ifdef HILDONANIMATION
+    show_hildon_animation(app->clutter_objects_in_popup_form, app->popup_window);
+//    gtk_widget_show_all(widget);
+    g_signal_handlers_disconnect_by_func(G_OBJECT(widget),G_CALLBACK(popup_simple_window_expose),NULL);
+#endif
+}
+/*******************************************************************************/
+void
+click_url_and_destroy_window(GtkWidget* button, gpointer window)
+{
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+
+    click_url(button);
+    gtk_widget_destroy(GTK_WIDGET(window));
+
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+
+}
+/*******************************************************************************/
+void donation_button_handler(void){
+    GtkWidget   *dialog, *url, *label;
+    gint    result;
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+
+#if !OS2009
+    dialog =
+        gtk_dialog_new_with_buttons(_("Donation"), NULL,
+                                    GTK_DIALOG_MODAL |
+                                    GTK_DIALOG_DESTROY_WITH_PARENT,
+                                    _("OK"), GTK_RESPONSE_ACCEPT, NULL);
+#else
+    dialog =
+        gtk_dialog_new_with_buttons(_("Donation"), NULL,
+                                    GTK_DIALOG_MODAL |
+                                    GTK_DIALOG_DESTROY_WITH_PARENT, NULL);
+
+#endif
+/* text */
+    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),
+                        label = gtk_label_new(_("You can make donation here: ")),
+                        FALSE, FALSE, 5);
+    set_font(label, NULL, 20);
+/* url */
+    url = gtk_button_new_with_label("http://omweather.garage.maemo.org/");
+    gtk_button_set_relief(GTK_BUTTON(url), GTK_RELIEF_NONE);
+    g_signal_connect(url, "clicked",
+          G_CALLBACK(click_url_and_destroy_window), dialog);
+    gtk_button_set_focus_on_click(GTK_BUTTON(url), FALSE);
+    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), url, FALSE, FALSE, 5);
+    set_font(url, NULL, 12);
+    gtk_widget_show_all(dialog);
+/* start dialog window */
+    result = gtk_dialog_run(GTK_DIALOG(dialog));
+    gtk_widget_destroy(dialog);
+}
+#endif
 
 
